from aiogram.types import Message

from src.models.crud.user_crud import fn_create_user, fn_update_user, fn_delete_user, fn_get_user
from src.settings import settings
from src.utils.debug_mode import debug_message
from src.utils.decorators import bot_action, BotParam


@bot_action('userbot add user', params=[
    BotParam('username', r'[\w\d]+'),
])
async def add_user(message: Message, username: str, state):
    await debug_message(message, f"Trying to add user '{username}'")
    await fn_create_user(settings.engine, name=username)
    await message.reply('User added successfully.')


@bot_action('userbot update user', params=[
    BotParam('old_username', r'[\w\d]+'),
    BotParam('new_username', r'[\w\d]+'),
])
async def update_user(message: Message, old_username: str, new_username: str, state):
    await debug_message(message, f"Trying to change username from '{old_username}' to '{new_username}'")
    await fn_update_user(settings.engine, old_username=old_username, new_username=new_username)
    await message.reply('User updated successfully.')


@bot_action('userbot delete user', params=[
    BotParam('username', r'[\w\d]+'),
])
async def update_user(message: Message, username: str, state):
    await debug_message(message, f"Trying to delete user '{username}'")
    await fn_delete_user(settings.engine, username)
    await message.reply('User deleted successfully.')


@bot_action('userbot list')
async def list_users(message: Message, state):
    await debug_message(message, f"Listing users")
    users = await fn_get_user(settings.engine)
    msg_text = "User database empty."
    if users:
        msg_text = "\n".join([f"{user.ID}: {user.name}" for user in users])
    await message.reply(msg_text)
