from typing import Optional, List

from aiopg.sa import Engine

from src.models.user import User


async def fn_create_user(engine: Engine, *, name: str):
    insert_query = User.__table__.insert().values(
        name=name
    )
    async with engine.acquire() as conn:
        await conn.execute(insert_query)


async def fn_get_user(engine: Engine, *,
                      user_id: Optional[int] = None,
                      user_name: Optional[str] = None) -> List[User]:
    select_query = User.__table__.select()
    if user_id:
        select_query = select_query.filter(User.ID == user_id)
    if user_name:
        select_query = select_query.filter(User.name == user_name)

    async with engine.acquire() as conn:
        cursor = await conn.execute(select_query)
        return await cursor.fetchall()


async def fn_delete_user(engine: Engine, *user_names: str):
    delete_query = User.__table__.delete().where(User.name.in_(user_names))
    async with engine.acquire() as connection:
        await connection.execute(delete_query)


async def fn_update_user(engine: Engine, *,
                         old_username: str,
                         new_username: str):
    update_query = User.__table__.update().where(User.name == old_username).values(name=new_username)
    async with engine.acquire() as conn:
        await conn.execute(update_query)
