from aiogram import Dispatcher
from aiopg.sa import Engine
from pydantic import BaseSettings
from pydantic.fields import Field

__all__ = ['settings']


class Settings(BaseSettings):
    bot_token: str = Field(name='bot_token',
                           default='',
                           env='TELEGRAM_BOT_TOKEN',
                           required=True)

    proxy_pass: str = Field(name='proxy_pass',
                            default=None,
                            env='PROXY_PASS',
                            required=True)

    postgres_user: str = Field(name='postgres_user',
                               default='postgres',
                               env='POSTGRES_USER')

    postgres_password: str = Field(name='postgres_password',
                                   default=None,
                                   env='POSTGRES_PASSWORD',
                                   required=True)

    postgres_database: str = Field(name='postgres_database',
                                   default=None,
                                   env='POSTGRES_DB',
                                   required=True)

    postgres_host: str = Field(name='postgres_host',
                               default='localhost',
                               env='POSTGRES_HOST')

    postgres_port: int = Field(name='postgres_port',
                               default=5432,
                               env='POSTGRES_PORT')

    app_mode: str = Field(name='app_mode',
                          default='dev',
                          env='APP_MODE')

    engine: Engine = None
    dispatcher: Dispatcher = None
    debug_mode: bool = False


settings = Settings()
